@@ -137,7 +137,7 @@ setMethod("rast", signature(x="SpatVector"),
 }
 
 setMethod("rast", signature(x="character"),
-	function(x, subds=0) {
+	function(x, subds=0, opts=NULL) {
 
 		x <- trimws(x)
 		x <- x[x!=""]
@@ -147,11 +147,12 @@ setMethod("rast", signature(x="character"),
 		r <- methods::new("SpatRaster")
 		f <- .fullFilename(x)
 		#subds <- subds[1]
+		if (is.null(opts)) opts <- ""[0]
 		if (is.character(subds)) { 
 			#r@ptr <- SpatRaster$new(f, -1, subds, FALSE, 0[])
-			r@ptr <- SpatRaster$new(f, -1, subds, FALSE, 0[])
+			r@ptr <- SpatRaster$new(f, -1, subds, FALSE, opts, 0[])
 		} else {
-			r@ptr <- SpatRaster$new(f, subds-1, "", FALSE, 0[])
+			r@ptr <- SpatRaster$new(f, subds-1, "", FALSE, opts, 0[])
 		}
 		r <- messages(r, "rast")
 		if (r@ptr$getMessage() == "ncdf extent") {
@@ -174,40 +175,47 @@ setMethod("rast", signature(x="character"),
 
 multi <- function(x, subds=0, xyz=c(1,2,3)) {
 
-		x <- trimws(x)
-		x <- x[x!=""]
-		if (length(x) == 0) {
-			error("rast,character", "provide a valid filename")
-		}
-		r <- methods::new("SpatRaster")
-		f <- .fullFilename(x)
-		#subds <- subds[1]
-		if (is.character(subds)) { 
-			r@ptr <- SpatRaster$new(f, -1, subds, TRUE, xyz-1)
-		} else {
-			r@ptr <- SpatRaster$new(f, subds-1, "", TRUE, xyz-1)
-		}
-		if (r@ptr$getMessage() == "ncdf extent") {
-			test <- try(r <- .ncdf_extent(r), silent=TRUE)
-			if (inherits(test, "try-error")) {
-				warn("rast", "GDAL did not find an extent. Cells not equally spaced?") 
-			}
-		}
-		r <- messages(r, "rast")
-
-		if (crs(r) == "") {
-			if (is.lonlat(r, perhaps=TRUE, warn=FALSE)) {
-				crs(r) <- "OGC:CRS84"
-			}
-		}
-		r
+	x <- trimws(x)
+	x <- x[x!=""]
+	if (length(x) == 0) {
+		error("rast,character", "provide a valid filename")
 	}
+	r <- methods::new("SpatRaster")
+	f <- .fullFilename(x)
+	#subds <- subds[1]
+	if (is.character(subds)) { 
+		r@ptr <- SpatRaster$new(f, -1, subds, TRUE, xyz-1)
+	} else {
+		r@ptr <- SpatRaster$new(f, subds-1, "", TRUE, xyz-1)
+	}
+	if (r@ptr$getMessage() == "ncdf extent") {
+		test <- try(r <- .ncdf_extent(r), silent=TRUE)
+		if (inherits(test, "try-error")) {
+			warn("rast", "GDAL did not find an extent. Cells not equally spaced?") 
+		}
+	}
+	r <- messages(r, "rast")
+
+	if (crs(r) == "") {
+		if (is.lonlat(r, perhaps=TRUE, warn=FALSE)) {
+			crs(r) <- "OGC:CRS84"
+		}
+	}
+	r
+}
 
 
 setMethod("rast", signature(x="SpatRaster"),
-	function(x, nlyrs=nlyr(x), time=FALSE, props=FALSE) {
+	function(x, nlyrs=nlyr(x), names, vals, time=FALSE, props=FALSE) {
 		x@ptr <- x@ptr$geometry(nlyrs, props, time)
-		messages(x, "rast")
+		x <- messages(x, "rast")
+		if (!missing(names)) {
+			if (length(names) == nlyr(x)) names(x) <- names
+		}
+		if (!missing(vals)) {
+			values(x) <- vals
+		}
+		x
 	}
 )
 
